@@ -20,8 +20,8 @@ r3 = r2 + (0, 75, 0, 75)
 t = "¡Un pequeño texto para practicar!"
 
 # add 3 annots, modify the last one somewhat
-a1 = page.add_freetext_annot(r1, t, text_color=red, border_color=red)
-a2 = page.add_freetext_annot(r2, t, fontname="Ti", text_color=blue, border_color=blue)
+a1 = page.add_freetext_annot(r1, t, text_color=red)
+a2 = page.add_freetext_annot(r2, t, fontname="Ti", text_color=blue)
 a3 = page.add_freetext_annot(r3, t, fontname="Co", text_color=blue, rotate=90)
 a3.set_border(width=0)
 a3.update(fontsize=8, fill_color=gold)
