@@ -32,10 +32,11 @@ def test_2548():
     # This checks that PyMuPDF 1.23.7 fixes this bug, and also that earlier
     # versions with updated MuPDF also fix the bug.
     rebased = hasattr(pymupdf, 'mupdf')
-    if pymupdf.mupdf_version_tuple >= (1, 25):
-        expected = 'format error: cycle in structure tree\nstructure tree broken, assume tree is missing'
+    if pymupdf.mupdf_version_tuple >= (1, 27):
+        expected = 'format error: No common ancestor in structure tree\nstructure tree broken, assume tree is missing'
+        expected = '\n'.join([expected] * 5)
     else:
-        expected = 'Loop found in structure tree. Ignoring structure.'
+        expected = 'format error: cycle in structure tree\nstructure tree broken, assume tree is missing'
     if rebased:
         assert wt == expected, f'expected:\n    {expected!r}\nwt:\n    {wt!r}\n'
     assert not e
