@@ -16,7 +16,3 @@ def test_2907():
     pdf_pages = list(fitz_document.pages())
     (page,) = pdf_pages
     page.clean_contents()
-    if pymupdf.mupdf_version_tuple < (1, 24, 2):
-        # We expect 'dropping unclosed PDF processor' warnings.
-        wt = pymupdf.TOOLS.mupdf_warnings()
-        assert wt
