@@ -1,8 +1,11 @@
 import os
 import io
 from pprint import pprint
-import pymupdf
+import textwrap
 import pickle
+import platform
+
+import pymupdf
 
 scriptdir = os.path.abspath(os.path.dirname(__file__))
 filename = os.path.join(scriptdir, "resources", "chinese-tables.pdf")
@@ -180,11 +183,29 @@ def test_2979():
         pymupdf.TOOLS.set_small_glyph_heights() is False
     ), f"{pymupdf.TOOLS.set_small_glyph_heights()=}"
 
+    wt = pymupdf.TOOLS.mupdf_warnings()
+    if pymupdf.mupdf_version_tuple >= (1, 26, 8):
+        assert (
+            wt
+            == "bogus font ascent/descent values (3117 / -2463)\n... repeated 2 times...\nActualtext with no position. Text may be lost or mispositioned.\n... repeated 96 times..."
+        )
+    elif pymupdf.mupdf_version_tuple >= (1, 26, 0):
+        assert (
+            wt
+            == "bogus font ascent/descent values (3117 / -2463)\n... repeated 2 times..."
+        )
+    else:
+        assert not wt
+
 
 def test_3062():
     """Tests the fix for #3062.
     After table extraction, a rotated page should behave and look
     like as before."""
+    if platform.python_implementation() == 'GraalVM':
+        print(f'test_3062(): Not running because slow on GraalVM.')
+        return
+    
     filename = os.path.join(scriptdir, "resources", "test_3062.pdf")
     doc = pymupdf.open(filename)
     page = doc[0]
@@ -212,6 +233,10 @@ def test_strict_lines():
 
 def test_add_lines():
     """Test new parameter add_lines for table recognition."""
+    if platform.python_implementation() == 'GraalVM':
+        print(f'test_add_lines(): Not running because breaks later tests on GraalVM.')
+        return
+    
     filename = os.path.join(scriptdir, "resources", "small-table.pdf")
     doc = pymupdf.open(filename)
     page = doc[0]
@@ -285,15 +310,70 @@ def test_markdown():
     doc = pymupdf.open(filename)
     page = doc[0]
     tab = page.find_tables(strategy="lines_strict")[0]
-    text = (
-        "|Header1|Header2|Header3|\n"
-        "|---|---|---|\n"
-        "|Col11 Col12|Col21 Col22|Col31 Col32 Col33|\n"
-        "|Col13|Col23|Col34 Col35|\n"
-        "|Col14|Col24|Col36|\n"
-        "|Col15|Col25 Col26||\n\n"
-    )
-    assert tab.to_markdown() == text
+    if pymupdf.mupdf_version_tuple < (1, 26, 3):
+        md_expected = textwrap.dedent('''
+                |Header1|Header2|Header3|
+                |---|---|---|
+                |Col11<br>Col12|~~Col21~~<br>~~Col22~~|Col31<br>Col32<br>Col33|
+                |Col13|~~Col23~~|Col34<br>Col35|
+                |Col14|~~Col24~~|Col36|
+                |Col15|~~Col25~~<br>~~Col26~~||
+                
+                ''').lstrip()
+    else:
+        md_expected = (
+            "|Header1|Header2|Header3|\n"
+            "|---|---|---|\n"
+            "|Col11<br>Col12|Col21<br>Col22|Col31<br>Col32<br>Col33|\n"
+            "|Col13|Col23|Col34<br>Col35|\n"
+            "|Col14|Col24|Col36|\n"
+            "|Col15|Col25<br>Col26||\n\n"
+        )
+
+
+    md = tab.to_markdown()
+    assert md == md_expected, f'Incorrect md:\n{textwrap.indent(md, "    ")}'
+
+
+def test_paths_param():
+    """Confirm acceptance of supplied vector graphics list."""
+    filename = os.path.join(scriptdir, "resources", "strict-yes-no.pdf")
+    doc = pymupdf.open(filename)
+    page = doc[0]
+    tabs = page.find_tables(paths=[])  # will cause all tables are missed
+    assert tabs.tables == []
+
+
+def test_boxes_param():
+    """Confirm acceptance of supplied boxes list."""
+    filename = os.path.join(scriptdir, "resources", "small-table.pdf")
+    doc = pymupdf.open(filename)
+    page = doc[0]
+    paths = page.get_drawings()
+    box0 = page.cluster_drawings(drawings=paths)[0]
+    boxes = [box0]
+    words = page.get_text("words")
+    x_vals = [w[0] - 5 for w in words if w[4] in ("min", "max", "avg")]
+    for x in x_vals:
+        r = +box0
+        r.x1 = x
+        boxes.append(r)
+
+    y_vals = sorted(set([round(w[3]) for w in words]))
+    for y in y_vals[:-1]:  # skip last one to avoid empty row
+        r = +box0
+        r.y1 = y
+        boxes.append(r)
+
+    tabs = page.find_tables(paths=[], add_boxes=boxes)
+    tab = tabs.tables[0]
+    assert tab.extract() == [
+        ["Boiling Points °C", "min", "max", "avg"],
+        ["Noble gases", "-269", "-62", "-170.5"],
+        ["Nonmetals", "-253", "4827", "414.1"],
+        ["Metalloids", "335", "3900", "741.5"],
+        ["Metals", "357", ">5000", "2755.9"],
+    ]
 
 
 def test_dotted_grid():
@@ -311,43 +391,75 @@ def test_dotted_grid():
 
 
 def test_4017():
-    path = os.path.normpath(f'{__file__}/../../tests/resources/test_4017.pdf')
+    path = os.path.normpath(f"{__file__}/../../tests/resources/test_4017.pdf")
     with pymupdf.open(path) as document:
         page = document[0]
-        
+
         tables = page.find_tables(add_lines=None)
         print(f"{len(tables.tables)=}.")
         tables_text = list()
         for i, table in enumerate(tables):
-            print(f'## {i=}.')
+            print(f"## {i=}.")
             t = table.extract()
             for tt in t:
-                print(f'    {tt}')
-        
+                print(f"    {tt}")
+
         # 2024-11-29: expect current incorrect output for last two tables.
-        
+
         expected_a = [
-                ['Class A/B Overcollateralization', '131.44%', '>=', '122.60%', '', 'PASS'],
-                [None, None, None, None, None, 'PASS'],
-                ['Class D Overcollateralization', '112.24%', '>=', '106.40%', '', 'PASS'],
-                [None, None, None, None, None, 'PASS'],
-                ['Event of Default', '156.08%', '>=', '102.50%', '', 'PASS'],
-                [None, None, None, None, None, 'PASS'],
-                ['Class A/B Interest Coverage', 'N/A', '>=', '120.00%', '', 'N/A'],
-                [None, None, None, None, None, 'N/A'],
-                ['Class D Interest Coverage', 'N/A', '>=', '105.00%', '', 'N/A'],
-                ]
+            ["Class A/B Overcollateralization", "131.44%", ">=", "122.60%", "", "PASS"],
+            [None, None, None, None, None, "PASS"],
+            ["Class D Overcollateralization", "112.24%", ">=", "106.40%", "", "PASS"],
+            [None, None, None, None, None, "PASS"],
+            ["Event of Default", "156.08%", ">=", "102.50%", "", "PASS"],
+            [None, None, None, None, None, "PASS"],
+            ["Class A/B Interest Coverage", "N/A", ">=", "120.00%", "", "N/A"],
+            [None, None, None, None, None, "N/A"],
+            ["Class D Interest Coverage", "N/A", ">=", "105.00%", "", "N/A"],
+        ]
         assert tables[-2].extract() == expected_a
-                
+
         expected_b = [
-                ["Moody's Maximum Rating Factor Test", '2,577', '<=', '3,250', '', 'PASS', '2,581'],
-                [None, None, None, None, None, 'PASS', None],
-                ['Minimum Floating Spread', '3.5006%', '>=', '2.0000%', '', 'PASS', '3.4871%'],
-                [None, None, None, None, None, 'PASS', None],
-                ['Minimum Weighted Average S&P Recovery\nRate Test', '40.50%', '>=', '40.00%', '', 'PASS', '40.40%'],
-                [None, None, None, None, None, 'PASS', None],
-                ['Weighted Average Life', '4.83', '<=', '9.00', '', 'PASS', '4.92'],
-                ]
+            [
+                "Moody's Maximum Rating Factor Test",
+                "2,577",
+                "<=",
+                "3,250",
+                "",
+                "PASS",
+                "2,581",
+            ],
+            [None, None, None, None, None, "PASS", None],
+            [
+                "Minimum Floating Spread",
+                "3.5006%",
+                ">=",
+                "2.0000%",
+                "",
+                "PASS",
+                "3.4871%",
+            ],
+            [None, None, None, None, None, "PASS", None],
+            [
+                "Minimum Weighted Average S&P Recovery\nRate Test",
+                "40.50%",
+                ">=",
+                "40.00%",
+                "",
+                "PASS",
+                "40.40%",
+            ],
+            [None, None, None, None, None, "PASS", None],
+            ["Weighted Average Life", "4.83", "<=", "9.00", "", "PASS", "4.92"],
+        ]
         assert tables[-1].extract() == expected_b
-                
-        
+
+
+def test_md_styles():
+    """Test output of table with MD-styled cells."""
+    filename = os.path.join(scriptdir, "resources", "test-styled-table.pdf")
+    doc = pymupdf.open(filename)
+    page = doc[0]
+    tabs = page.find_tables()[0]
+    text = """|Column 1|Column 2|Column 3|\n|---|---|---|\n|Zelle (0,0)|**Bold (0,1)**|Zelle (0,2)|\n|~~Strikeout (1,0), Zeile 1~~<br>~~Hier kommt Zeile 2.~~|Zelle (1,1)|~~Strikeout (1,2)~~|\n|**`Bold-monospaced`**<br>**`(2,0)`**|_Italic (2,1)_|**_Bold-italic_**<br>**_(2,2)_**|\n|Zelle (3,0)|~~**Bold-strikeout**~~<br>~~**(3,1)**~~|Zelle (3,2)|\n\n"""
+    assert tabs.to_markdown() == text
